@@ -3,18 +3,18 @@ from .core import (
     FileStore,
     MemoryStore,
     ObjectStore,
-    cache_decor,
+    decor,
     make_file_state_fn,
 )
 
 __author__ = "Samuel Grayson"
 __email__ = "sam+dev@samgrayson.me"
-__version__ = "0.1.0"
+__version__ = "0.3.0"
 __license__ = "MPL-2.0"
 __copyright__ = "2020 Samuel Grayson"
 
 __all__ = [
-    "cache_decor",
+    "decor",
     "DirectoryStore",
     "FileStore",
     "MemoryStore",
